4.9.1 (2025-02-12)
==================
👷 Bug fix
-----------

rql: remove superfluous quotes in the FTIHL functions (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/1107)

4.9.0 (2025-01-28)
==================

🛡 Security
-----------

Force to use waitress 3.0.2 or more (see CVE-2024-49768)

🎉 New features
---------------

- add a new FTIHL RQL function to mark searched terms (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/1085)
- add a new GROUP_LIST RQL function (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/1089)
- add variables to result sets produced by insert queries
- add variables to ResultSet created from RQL union with one single query
- server: improve the error message when a RQL fails
- stop using "default-dest-addrs" config address for reply-to (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/1088)

👷 Bug fixes
------------

- In ResulSet, correctly name columns containing variable method calls
- pyramid: wsgicors' maxage is expected to be a string
- When using sqlite, ensure that integer values returned from db are casted to boolean when necessary
- querier: resolve entity methods/attributes when solution is not known statically (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/1073)

📝 Documentation
----------------

- compare RQL with OpenCypher and GQL (Graph Query Language)
- explain how to remove an entity through RQL with only its eid
- improve the explaination of how to migrate to CW4 from CW3
